Builder

Struct Builder 

pub struct Builder { /* private fields */ }
Builder for an ntex runtime system.

Use build to create a SystemRunner, then run the event loop or block on a future.

Implementations

Source

impl Builder

pub fn name<N: AsRef<str>>(self, name: N) -> Self

Sets the name of the System.

pub fn signals(self, eanbled: bool) -> Self

Enables or disables process signal handling.

By default, signal handling is disabled.

pub fn panic_handling(self, eanbled: bool) -> Self

Enables panic handling.

When panic handling is enabled, the application can receive Signal::Panic(PanicReason::Panic(..)) signals. By default, panic handling is disabled.

pub fn stack_size(self, size: usize) -> Self

Sets the size of the stack (in bytes) for the new worker thread.

pub fn ping_interval(self, interval: usize) -> Self

Sets the ping interval for spawned arbiters.

The interval is specified in milliseconds and defaults to 2,000. Set it to zero to disable pings.

pub fn ping_threshold(self, interval: usize) -> Self

Sets the ping response threshold.

If a response takes too long, an attempt is made to create a backtrace for the busy arbiter.

The threshold is specified in milliseconds and defaults to 1,000.

pub fn thread_pool_limit(self, value: usize) -> Self

Sets the maximum number of blocking thread-pool workers.

The default is 256.

pub fn testing(self) -> Self

Configures the system for testing.

This disables signal and panic handling.

pub fn thread_pool_recv_timeout<T>(self, timeout: T) -> Self
where Duration: From<T>,

Sets how long an idle blocking worker waits before exiting.

The default is 60 seconds.

pub fn build<R: Runner>(self, runner: R) -> SystemRunner

Creates a system runner using the specified runtime runner.

Panics

Panics if the runtime cannot be created.

pub fn build_with(self, config: SystemConfig) -> SystemRunner

Creates a system runner from an existing system configuration.

Panics

Panics if the runtime cannot be created.