System

Struct System 

pub struct System(/* private fields */);
System is a runtime manager

Implementations

Source

impl System

pub fn build() -> Builder

Build a new system with a customized runtime

This allows to customize the runtime. See struct level docs on Builder for more information.

pub fn new<R: Runner>(name: &str, runner: R) -> SystemRunner

Create new system

This method panics if it can not create runtime

pub fn with_config(name: &str, config: SystemConfig) -> SystemRunner

Create new system

This method panics if it can not create runtime

pub fn current() -> System

Get current running system

Panics

Panics if System is not running

pub fn try_current() -> Option<System>

Runs a function using the system context.

pub fn id(&self) -> Id

System id

pub fn name(&self) -> &str

System name

pub fn stop(&self)

Stop the system

pub fn stop_with_code(&self, code: i32)

Stop the system with a particular exit code

pub fn signals(&self) -> bool

Return status of signals option

pub fn enable_signals(&self)

Enable signals handling

pub fn disable_signals(&self)

Disable signals handling

pub fn arbiter(&self) -> Arbiter

System arbiter

Panics

Panics if system is not started

pub fn list_arbiters<F, R>(&self, f: F) -> R
where F: FnOnce(&[Arbiter]) -> R,

Retrieves a list of all arbiters in the system

This method should be called from the thread where the system has been initialized, typically the “main” thread.

pub fn list_arbiter_pings<F>(f: F)
where F: FnMut(&Arbiter, &mut VecDeque<PingRecord>),

Retrieves a list of last pings records for each worker.

This method should be called from the thread where the system has been initialized, typically the “main” thread.

pub fn config(&self) -> SystemConfig

System config

pub fn handle(&self) -> Handle

Runtime handle for main thread

pub fn testing(&self) -> bool

Testing flag

pub fn spawn_blocking<F, R>(&self, f: F) -> BlockingResult<R>
where F: FnOnce() -> R + Send + 'static, R: Send + 'static,

Spawns a blocking task on a new thread and waits for it to complete.

If the returned future is dropped, the blocking task is cancelled. Call detach to allow the task to continue running in the background.

pub fn get_value<T>(&self, f: impl FnOnce() -> T) -> T
where T: Clone + Send + Sync + 'static,

Returns a previously registered type, or inserts and returns a new one.

This method acquires a lock on the internal data structure. To avoid repeated locking, prefer storing a cloned value in the arbiter’s storage.