pub struct SystemRunner { /* private fields */ }Expand description
A configured system that has not yet started its event loop.
Implementations
Sourceimpl SystemRunner
impl SystemRunner
Sourcepub fn run_until_stop(self) -> Result<()>
pub fn run_until_stop(self) -> Result<()>
Runs the event loop until System::stop() is called.
Sourcepub fn run<F>(self, f: F) -> Result<()>
pub fn run<F>(self, f: F) -> Result<()>
Runs f, then drives the event loop until System::stop() is called.