pub fn spawn_blocking<F, R>(f: F) -> BlockingResult<R> ⓘExpand description
Spawns a blocking task on a new thread and waits for it to complete.
If the returned future is dropped, the blocking task is cancelled.
Call detach to allow the task to continue running in the background.