pub struct Arbiter(/* private fields */);Expand description
An asynchronous execution environment running on one OS thread.
Creating an arbiter starts a thread with its own local event loop. Futures
spawned on that event loop are not required to implement Send.
Implementations
Sourceimpl Arbiter
impl Arbiter
Sourcepub fn current() -> Arbiter
pub fn current() -> Arbiter
Returns the arbiter running on the current thread.
Panics
Panics if no arbiter is running on the current thread.
Sourcepub fn new() -> Arbiter
pub fn new() -> Arbiter
Starts an arbiter on a new thread with an automatically generated name.
Sourcepub fn with_name(name: String) -> Arbiter
pub fn with_name(name: String) -> Arbiter
Starts an arbiter on a new thread with the specified name.
Sourcepub fn is_running(&self) -> bool
pub fn is_running(&self) -> bool
Returns whether the arbiter is running.
Sourcepub fn get_value<T, F>(f: F) -> T
pub fn get_value<T, F>(f: F) -> T
Returns a value from thread-local arbiter storage, inserting it if absent.