Arbiter

Struct Arbiter 

pub struct Arbiter(/* private fields */);
An asynchronous execution environment running on one OS thread.

Creating an arbiter starts a thread with its own local event loop. Futures spawned on that event loop are not required to implement Send.

Implementations

Source

impl Arbiter

pub fn current() -> Arbiter

Returns the arbiter running on the current thread.

Panics

Panics if no arbiter is running on the current thread.

pub fn stop(&self)

Requests that the arbiter stop its event loop.

pub fn new() -> Arbiter

Starts an arbiter on a new thread with an automatically generated name.

pub fn with_name(name: String) -> Arbiter

Starts an arbiter on a new thread with the specified name.

pub fn id(&self) -> Id

Returns the arbiter identifier.

pub fn name(&self) -> &str

Returns the arbiter name.

pub fn handle(&self) -> &Handle

Returns a handle to the arbiter’s runtime.

pub fn is_running(&self) -> bool

Returns whether the arbiter is running.

pub fn get_value<T, F>(f: F) -> T
where T: Clone + 'static, F: FnOnce() -> T,

Returns a value from thread-local arbiter storage, inserting it if absent.

pub fn on_stop<F>(self, f: F) -> Self
where F: Fn() + Send + Sync + 'static,

Adds a callback to run after the arbiter stops.

pub fn join(&mut self) -> Result<()>

Waits for the arbiter’s thread to stop.

This returns immediately for an arbiter that does not own a thread handle, including the system’s primary arbiter.