Arbiter

Struct Arbiter 

pub struct Arbiter { /* private fields */ }
Arbiters provide an asynchronous execution environment for actors, functions and futures.

When an Arbiter is created, it spawns a new OS thread, and hosts an event loop. Some Arbiter functions execute on the current thread.

Implementations

Source

impl Arbiter

pub fn current() -> Arbiter

Returns the current thread’s arbiter’s address

Panics

Panics if Arbiter is not running

pub fn stop(&self)

Stop arbiter from continuing it’s event loop.

pub fn new() -> Arbiter

Spawn new thread and run runtime in spawned thread. Returns address of newly created arbiter.

pub fn with_name(name: String) -> Arbiter

Spawn new thread and run runtime in spawned thread

Returns address of newly created arbiter.

pub fn id(&self) -> Id

Id of the arbiter

pub fn name(&self) -> &str

Name of the arbiter

pub fn handle(&self) -> &Handle

Handle to a runtime

pub fn get_value<T, F>(f: F) -> T
where T: Clone + 'static, F: FnOnce() -> T,

Get a type previously inserted to this runtime or create new one.

pub fn join(&mut self) -> Result<()>

Wait for the event loop to stop by joining the underlying thread (if have Some).