pub struct Arbiter { /* private fields */ }Expand description
Arbiters provide an asynchronous execution environment for actors, functions and futures.
When an Arbiter is created, it spawns a new OS thread, and hosts an event loop. Some Arbiter functions execute on the current thread.
Implementations
Sourceimpl Arbiter
impl Arbiter
Sourcepub fn new() -> Arbiter
pub fn new() -> Arbiter
Spawn new thread and run runtime in spawned thread. Returns address of newly created arbiter.
Sourcepub fn with_name(name: String) -> Arbiter
pub fn with_name(name: String) -> Arbiter
Spawn new thread and run runtime in spawned thread
Returns address of newly created arbiter.